@@ -357,6 +357,9 @@ class FlaskService:
                         worker_class=worker_class,
                         log_level=log_level,
                     ),
+                    caching=f"""RUN ["venv/bin/python", "-c", "from {service_script} import app"]
+ENV TRANSFORMERS_OFFLINE=1
+""",
                 )
             )
 
