@@ -1,4 +1,5 @@
 from numbers import Number
+from typing import Any
 
 from pydantic import BaseModel
 
@@ -27,3 +28,16 @@ class Annotation(BaseModel):
     class Config:
         alias_generator = to_camel
         arbitrary_types_allowed = True
+
+    def json(self, **kwargs: Any) -> str:
+        if "exclude_none" not in kwargs.keys():
+            kwargs["exclude_none"] = True
+        return super().json(**kwargs)
+
+    def __getitem__(self, key):
+        return getattr(self, key)
+
+    def get(self, key, value: Any = None):
+        if hasattr(self, key):
+            return getattr(self, key)
+        return value
