@@ -32,3 +32,11 @@ class ResponseObject(BaseModel):
         if "exclude_none" not in kwargs.keys():
             kwargs["exclude_none"] = True
         return super().json(**kwargs)
+
+    def __getitem__(self, key):
+        return getattr(self, key)
+
+    def get(self, key, value: Any = None):
+        if hasattr(self, key):
+            return getattr(self, key)
+        return value
