@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from .. import Annotation, Request
 
@@ -43,3 +43,12 @@ class TextRequest(Request):
         with open(filename) as f:
             content = f.read()
         return cls(content=content, features=features, annotations=annotations, params=params)
+
+    @classmethod
+    def from_auto_content(cls, content: Any):
+        if isinstance(content, str):
+            return cls(content=content)
+        elif isinstance(content, dict):
+            return cls(**content)
+        else:
+            raise ValueError(f"The TextRequest message cannot be initialize from {content}")
