@@ -585,7 +585,7 @@ class QuartService:
             path = Path(inspect.getsourcefile(cls))
         else:
             path = Path(path)
-        required_files = [path.name] + required_files
+        required_files = [path.name] + ["prepare.py"] + required_files
         required_folders = "\n".join(
             [COPY_FOLDER.format(folder_name=str(Path(folder))) for folder in required_folders]
         )
@@ -596,6 +596,18 @@ class QuartService:
         # on Windows.  To ensure this we write in binary mode.
         with open(path.parent / "docker-entrypoint.sh", "wb") as f:
             f.write(ENTRYPOINT_QUART.format(service_script=service_script).encode("utf-8"))
+        with open(path.parent / "prepare.py", "w") as f:
+            f.write(
+                f"""import asyncio
+            
+async def prepare():
+    from {service_script} import app
+    await app.startup()
+    await app.shutdown()
+
+asyncio.run(prepare())
+"""
+            )
         with open(path.parent / "Dockerfile", "w") as f:
             f.write(
                 DOCKERFILE.format(
@@ -604,6 +616,9 @@ class QuartService:
                     required_folders=required_folders,
                     commands="\n".join(commands),
                     env=ENV_QUART.format(log_level=log_level),
+                    caching=f"""RUN ["venv/bin/python", "prepare.py"]
+ENV TRANSFORMERS_OFFLINE=1
+""",
                 )
             )
 
