@@ -377,7 +377,7 @@ class Service(Entity, NeedAuthentication):
         Args:
             request_input (Union[str, List[str], Request]): can be the text to process directly, the name of the file to process,
                 a list of texts, or directly a Request object.
-            request_type (str, optional): precise the type of the request. Can be "text", "structuredText", "audio", or "audioStream".
+            request_type (str, optional): precise the type of the request. Can be "text", "structuredText", "audio", "audioStream", "image", or "imageStream".
                 It is only used if request_input is not a Request object. Defaults to "text".
             sync_mode (bool, optional): True to use the sync_mode. Defaults to False.
             timeout (int, optional): number of seconds before timeout. Defaults to None.
@@ -452,31 +452,7 @@ class Service(Entity, NeedAuthentication):
 
         headers = {"Authorization": f"Bearer {self.authentication.access_token}"}
         post_kwargs = {}
-        # self.id == 0 corresponds to a service initialized from a docker image
-        if isinstance(request, AudioRequest) and self.id == 0:
-            files = {
-                "request": (
-                    None,
-                    json.dumps(
-                        {
-                            "type": "audio",
-                            "format": request.format,
-                            "sampleRate": request.sample_rate,
-                            "features": request.features,
-                            "annotations": request.annotations,
-                        }
-                    ),
-                    "application/json",
-                ),
-                "content": (
-                    None,
-                    request.content,
-                    "audio/x-wav" if request.format == "LINEAR16" else "audio/mpeg",
-                ),
-            }
-            data = None
-            post_kwargs = {"files": files}
-        elif isinstance(request, AudioRequest):
+        if isinstance(request, AudioRequest):
             data = request.content if request.content else request.generator
             post_kwargs["params"] = request.params
             headers["Content-Type"] = "audio/x-wav" if request.format == "LINEAR16" else "audio/mpeg"
