@@ -118,103 +118,119 @@ def map_metadatarecord_to_result(
             )
         )
         detail = None
-        licences = [
-            name
-            for terms in list(
-                map(
-                    lambda x: list(
-                        map(
-                            lambda x: get_en_value(
+        try:
+            licences = [
+                name
+                for terms in list(
+                    map(
+                        lambda x: list(
+                            map(
+                                lambda x: get_en_value(
+                                    get_information(
+                                        id,
+                                        x,
+                                        "licence_terms_name",
+                                        display_and_stat=display_and_stat,
+                                    )
+                                ),
                                 get_information(
                                     id,
                                     x,
-                                    "licence_terms_name",
+                                    "licence_terms",
                                     display_and_stat=display_and_stat,
-                                )
-                            ),
-                            get_information(
-                                id,
-                                x,
-                                "licence_terms",
-                                display_and_stat=display_and_stat,
-                            ),
-                        )
-                    ),
-                    get_information(
-                        id,
-                        described_entity,
-                        [
-                            "lr_subclass",
-                            "software_distribution" if resource_type == "ToolService" else "dataset_distribution",
-                        ],
-                        display_and_stat=display_and_stat,
-                    ),
+                                ),
+                            )
+                        ),
+                        get_information(
+                            id,
+                            described_entity,
+                            [
+                                "lr_subclass",
+                                "software_distribution" if resource_type == "ToolService" else "dataset_distribution",
+                            ],
+                            display_and_stat=display_and_stat,
+                        ),
+                    )
                 )
-            )
-            for name in terms
-        ]
-        if resource_type == "ToolService":
-            # input_content_resource
-            input_content_resource = get_information(
-                id,
-                described_entity,
-                ["lr_subclass", "input_content_resource"],
-                display_and_stat=display_and_stat,
-            )
-            # output_resource
-            output_resource = get_information(
-                id,
-                described_entity,
-                ["lr_subclass", "output_resource"],
-                display_and_stat=display_and_stat,
-            )
+                for name in terms
+            ]
+        except:
+            licences = []
+        try:
+            if resource_type == "ToolService":
+                # input_content_resource
+                input_content_resource = get_information(
+                    id,
+                    described_entity,
+                    ["lr_subclass", "input_content_resource"],
+                    display_and_stat=display_and_stat,
+                )
+                # output_resource
+                output_resource = get_information(
+                    id,
+                    described_entity,
+                    ["lr_subclass", "output_resource"],
+                    display_and_stat=display_and_stat,
+                )
+                languages = []
+                for resource in input_content_resource + output_resource:
+                    try:
+                        languages += [
+                            ISO639.LanguageName(l["language_id"])
+                            for l in get_information(id, resource, "language", display_and_stat=display_and_stat)
+                        ]
+                    except:
+                        continue
+            elif resource_type == "Corpus":
+                corpus_media_part = get_information(
+                    id,
+                    described_entity,
+                    ["lr_subclass", "corpus_media_part"],
+                    display_and_stat=display_and_stat,
+                )
+                languages = []
+                for media in corpus_media_part:
+                    try:
+                        languages += [
+                            ISO639.LanguageName(l["language_id"])
+                            for l in get_information(id, media, "language", display_and_stat=display_and_stat)
+                        ]
+                    except:
+                        continue
+            elif resource_type == "LanguageDescription":
+                language_description_media_part = get_information(
+                    id,
+                    described_entity,
+                    ["lr_subclass", "language_description_media_part"],
+                    display_and_stat=display_and_stat,
+                )
+                languages = []
+                for media in language_description_media_part:
+                    try:
+                        languages += [
+                            ISO639.LanguageName(l["language_id"])
+                            for l in get_information(id, media, "language", display_and_stat=display_and_stat)
+                        ]
+                    except:
+                        continue
+            elif resource_type == "LexicalConceptualResource":
+                lexical_conceptual_resource_media_part = get_information(
+                    id,
+                    described_entity,
+                    ["lr_subclass", "lexical_conceptual_resource_media_part"],
+                    display_and_stat=display_and_stat,
+                )
+                languages = []
+                for media in lexical_conceptual_resource_media_part:
+                    try:
+                        languages += [
+                            ISO639.LanguageName(l["language_id"])
+                            for l in get_information(id, media, "language", display_and_stat=display_and_stat)
+                        ]
+                    except:
+                        continue
+        except:
             languages = []
-            for resource in input_content_resource + output_resource:
-                languages += [
-                    ISO639.LanguageName(l["language_id"])
-                    for l in get_information(id, resource, "language", display_and_stat=display_and_stat)
-                ]
-        elif resource_type == "Corpus":
-            corpus_media_part = get_information(
-                id,
-                described_entity,
-                ["lr_subclass", "corpus_media_part"],
-                display_and_stat=display_and_stat,
-            )
-            languages = []
-            for media in corpus_media_part:
-                languages += [
-                    ISO639.LanguageName(l["language_id"])
-                    for l in get_information(id, media, "language", display_and_stat=display_and_stat)
-                ]
-        elif resource_type == "LanguageDescription":
-            language_description_media_part = get_information(
-                id,
-                described_entity,
-                ["lr_subclass", "language_description_media_part"],
-                display_and_stat=display_and_stat,
-            )
-            languages = []
-            for media in language_description_media_part:
-                languages += [
-                    ISO639.LanguageName(l["language_id"])
-                    for l in get_information(id, media, "language", display_and_stat=display_and_stat)
-                ]
-        elif resource_type == "LexicalConceptualResource":
-            lexical_conceptual_resource_media_part = get_information(
-                id,
-                described_entity,
-                ["lr_subclass", "lexical_conceptual_resource_media_part"],
-                display_and_stat=display_and_stat,
-            )
-            languages = []
-            for media in lexical_conceptual_resource_media_part:
-                languages += [
-                    ISO639.LanguageName(l["language_id"])
-                    for l in get_information(id, media, "language", display_and_stat=display_and_stat)
-                ]
-        else:
-            raise ValueError(f"Resource type: {resource_type} not implemented yet.")
         country_of_registration = None
         creation_date = get_information(id, record, "metadata_creation_date", display_and_stat=display_and_stat)
         last_date_updated = get_information(
@@ -396,8 +412,8 @@ def map_metadatarecord_to_result(
         "description": description,
         "keywords": keywords,
         "detail": detail,
-        "licences": licences,
-        "languages": languages,
+        "licences": list(set(licences)),
+        "languages": list(set(languages)),
         "country_of_registration": country_of_registration,
         "creation_date": creation_date,
         "last_date_updated": last_date_updated,
